"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AcceptHandler = void 0;
const portMapItem_1 = require("./portMapItem");
const bayLog_1 = require("../bayLog");
const channelWrapper_1 = require("./channelWrapper");
class AcceptHandler {
    constructor(agent, portMap) {
        this.chCount = 0;
        this.isShutdown = false;
        this.agent = agent;
        this.portMap = portMap;
    }
    onAccept(serverSkt, clientSkt) {
        let portDkr = portMapItem_1.PortMapItem.findDocker(serverSkt, this.portMap);
        bayLog_1.BayLog.debug("%s Accepted: skt=%s", this.agent, clientSkt.remoteAddress);
        try {
            portDkr.checkAdmitted(clientSkt);
            if (portDkr.isSecure()) {
                clientSkt = portDkr.getSecure().createTlsSocket(clientSkt, serverSkt);
            }
        }
        catch (e) {
            bayLog_1.BayLog.error_e(e);
            clientSkt.end();
            return;
        }
        let ch = new channelWrapper_1.ChannelWrapper(clientSkt);
        let tp = portDkr.newTransporter(this.agent, ch);
        this.agent.nonBlockingHandler.askToStart(ch);
        this.agent.nonBlockingHandler.askToRead(ch);
    }
    shutdown() {
        this.isShutdown = true;
    }
}
exports.AcceptHandler = AcceptHandler;
//# sourceMappingURL=acceptHandler.js.map