"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CommandReceiver = void 0;
const grandAgent_1 = require("./grandAgent");
const bayLog_1 = require("../bayLog");
const ioException_1 = require("../util/ioException");
const ioUtil_1 = require("../util/ioUtil");
class CommandReceiver {
    constructor(agent, commCh) {
        this.agent = agent;
        bayLog_1.BayLog.debug("%s Start", this);
        this.communicationChannel = commCh;
        this.communicationChannel.on('data', (buf) => {
            this.onRead(buf);
        });
        this.communicationChannel.on('error', (err) => {
            bayLog_1.BayLog.error_e(err, "%s Communication error", this);
            this.close();
        });
        this.communicationChannel.on('close', () => {
            bayLog_1.BayLog.debug("%s communication channel closed", this);
            this.agent.abort(null, 0);
        });
    }
    toString() {
        return "ComReceiver#" + this.agent.agentId;
    }
    onRead(buf) {
        try {
            let pos = 0;
            while (pos < buf.length) {
                let data64 = ioUtil_1.IOUtil.readInt64(buf, pos);
                //BayLog.debug("%s receive data %s", this.agent, data64);
                let cmd = Number(data64 >> BigInt(48));
                let arg1 = Number(data64 >> BigInt(32) & BigInt(0xffff));
                let arg2 = Number(data64 >> BigInt(16) & BigInt(0xffff));
                let arg3 = Number(data64 & BigInt(0xffff));
                bayLog_1.BayLog.debug("%s receive command %d: args=(%d, %d, %d)", this.agent, cmd, arg1, arg2, arg3);
                switch (cmd) {
                    case grandAgent_1.GrandAgent.CMD_RELOAD_CERT:
                        this.agent.reloadCert();
                        break;
                    case grandAgent_1.GrandAgent.CMD_MEM_USAGE:
                        this.agent.printUsage();
                        break;
                    case grandAgent_1.GrandAgent.CMD_SHUTDOWN:
                        this.agent.shutdown();
                        return;
                    case grandAgent_1.GrandAgent.CMD_ABORT:
                        this.agent.abort(); // -> exit if process mode
                        return;
                    case grandAgent_1.GrandAgent.CMD_FORK:
                        this.agent.fork(arg1, arg2); // -> exit if process mode
                        break;
                    default:
                        bayLog_1.BayLog.error("Unknown command: %d", cmd);
                }
                this.send(grandAgent_1.GrandAgent.CMD_OK);
                pos += 8;
            }
        }
        catch (e) {
            if (e instanceof ioException_1.IOException)
                bayLog_1.BayLog.error_e(e, "%s Command thread aborted(end)", this.agent);
            else
                throw e;
        }
        finally {
            //BayLog.debug("%s Command ended", this);
        }
    }
    send(cmd) {
        bayLog_1.BayLog.debug("%s send command %d", this, cmd);
        let data64 = (BigInt(cmd) << BigInt(48) & BigInt(0xffff000000000000));
        ioUtil_1.IOUtil.writeInt64(this.communicationChannel, data64);
    }
    end() {
        bayLog_1.BayLog.debug("%s end", this);
        try {
            this.send(grandAgent_1.GrandAgent.CMD_CLOSE);
        }
        catch (e) {
            bayLog_1.BayLog.error_e(e, "%s Write error", this.agent);
        }
        this.close();
    }
    close() {
        this.communicationChannel.end();
    }
}
exports.CommandReceiver = CommandReceiver;
//# sourceMappingURL=commandReceiver.js.map