"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BayDockers = void 0;
const bcfParser_1 = require("./bcf/bcfParser");
const bcfKeyVal_1 = require("./bcf/bcfKeyVal");
const strUtil_1 = require("./util/strUtil");
const bayException_1 = require("./bayException");
const bayMessage_1 = require("./bayMessage");
const symbol_1 = require("./symbol");
const bayLog_1 = require("./bayLog");
const dockerLoader_1 = require("./util/dockerLoader");
class BayDockers {
    static init(conf) {
        this.dockerMap = new Map();
        let p = new bcfParser_1.BcfParser();
        let doc = p.parse(conf);
        //if(BayServer.logLevel == BayServer.LOG_LEVEL_DEBUG)
        //    doc.print();
        for (const o of doc.contentList) {
            if (o instanceof bcfKeyVal_1.BcfKeyVal) {
                let kv = o;
                BayDockers.dockerMap.set(kv.key, kv.value);
            }
        }
    }
    /**
     * Create docker from ini file element
     * @param elm
     * @return
     * @throws BayException
     */
    static createDocker(elm, parent) {
        let alias = elm.getValue("docker");
        let d = this.createDockerByAlias(elm.name, alias);
        d.init(elm, parent);
        return d;
    }
    static createDockerByAlias(category, alias) {
        var key;
        if (strUtil_1.StrUtil.empty(alias)) {
            key = category;
        }
        else {
            key = category + ":" + alias;
        }
        let className = this.dockerMap.get(key);
        if (className == null)
            throw new bayException_1.BayException(bayMessage_1.BayMessage.get(symbol_1.Symbol.CFG_DOCKER_NOT_FOUND, key));
        try {
            return dockerLoader_1.DockerLoader.loadDocker(className);
        }
        catch (e) {
            bayLog_1.BayLog.error_e(e);
            throw new bayException_1.BayException(e);
        }
    }
}
exports.BayDockers = BayDockers;
//# sourceMappingURL=bayDockers.js.map