"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BayLog = void 0;
const bayMessage_1 = require("./bayMessage");
const symbol_1 = require("./symbol");
const strUtil_1 = require("./util/strUtil");
const util_1 = require("util");
class BayLog {
    static setLogLevel(s) {
        if (strUtil_1.StrUtil.eqIgnoreCase(s, "trace"))
            BayLog.logLevel = BayLog.LOG_LEVEL_TRACE;
        else if (strUtil_1.StrUtil.eqIgnoreCase(s, "debug"))
            BayLog.logLevel = BayLog.LOG_LEVEL_DEBUG;
        else if (strUtil_1.StrUtil.eqIgnoreCase(s, "info"))
            BayLog.logLevel = BayLog.LOG_LEVEL_INFO;
        else if (strUtil_1.StrUtil.eqIgnoreCase(s, "warn"))
            BayLog.logLevel = BayLog.LOG_LEVEL_WARN;
        else if (strUtil_1.StrUtil.eqIgnoreCase(s, "error"))
            BayLog.logLevel = BayLog.LOG_LEVEL_ERROR;
        else if (strUtil_1.StrUtil.eqIgnoreCase(s, "fatal"))
            BayLog.logLevel = BayLog.LOG_LEVEL_FATAL;
        else
            BayLog.warn(bayMessage_1.BayMessage.get(symbol_1.Symbol.INT_UNKNOWN_LOG_LEVEL, s));
    }
    static info(fmt, ...args) {
        BayLog.log(BayLog.LOG_LEVEL_INFO, 3, null, fmt, ...args);
    }
    static trace(fmt, ...args) {
        BayLog.log(BayLog.LOG_LEVEL_TRACE, 3, null, fmt, ...args);
    }
    static debug(fmt, ...args) {
        BayLog.log(BayLog.LOG_LEVEL_DEBUG, 3, null, fmt, ...args);
    }
    static debug_e(e, fmt = null, ...args) {
        BayLog.log(BayLog.LOG_LEVEL_DEBUG, 3, e, fmt, ...args);
    }
    static warn(fmt, ...args) {
        BayLog.log(BayLog.LOG_LEVEL_WARN, 3, null, fmt, ...args);
    }
    static warn_e(e, fmt, ...args) {
        BayLog.log(BayLog.LOG_LEVEL_WARN, 3, e, fmt, ...args);
    }
    static error(fmt, ...args) {
        BayLog.log(BayLog.LOG_LEVEL_ERROR, 3, null, fmt, ...args);
    }
    static error_e(e, fmt = null, ...args) {
        BayLog.log(BayLog.LOG_LEVEL_ERROR, 3, e, fmt, ...args);
    }
    static fatal(fmt, ...args) {
        BayLog.log(BayLog.LOG_LEVEL_FATAL, 3, null, fmt, ...args);
    }
    static fatal_e(e, fmt = null, ...args) {
        BayLog.log(BayLog.LOG_LEVEL_FATAL, 3, e, fmt, ...args);
    }
    static log(lvl, stackIndex, e, fmt, ...args) {
        if (lvl < BayLog.logLevel)
            return;
        if (fmt != null) {
            let msg = "";
            try {
                if (args == null || args.length == 0)
                    msg = (0, util_1.format)("%s", fmt);
                else
                    msg = (0, util_1.format)(fmt, ...args);
            }
            catch (e) {
                console.log(e.stack);
                msg = fmt;
            }
            let stackTop = new Error().stack.split("\n")[stackIndex];
            let m = stackTop.match(/^(.*)\((.*)\)$/);
            if (m != null)
                stackTop = m[1] + " " + m[2];
            m = stackTop.match(/^(.*)at(.*) (.*):(.*):(.*)$/);
            var file = "";
            var line = "";
            if (m) {
                file = m[3];
                line = m[4];
            }
            let pos = "(" + file + ":" + line + ")";
            let prefix = "[" + new Date().toLocaleString() + "] " + this.LOG_LEVEL_NAME[lvl] + ". ";
            console.log(prefix + msg + " " + pos);
        }
        if (e) {
            if (BayLog.isDebug() || lvl == BayLog.LOG_LEVEL_FATAL) {
                console.log(e.stack);
            }
            else {
                BayLog.log(lvl, stackIndex + 1, null, "%s", e.message);
            }
        }
    }
    static isDebug() {
        return BayLog.logLevel <= BayLog.LOG_LEVEL_DEBUG;
    }
    static isTrace() {
        return BayLog.logLevel <= BayLog.LOG_LEVEL_TRACE;
    }
}
BayLog.LOG_LEVEL_TRACE = 0;
BayLog.LOG_LEVEL_DEBUG = 1;
BayLog.LOG_LEVEL_INFO = 2;
BayLog.LOG_LEVEL_WARN = 3;
BayLog.LOG_LEVEL_ERROR = 4;
BayLog.LOG_LEVEL_FATAL = 5;
/** Log level */
BayLog.logLevel = BayLog.LOG_LEVEL_INFO;
BayLog.LOG_LEVEL_NAME = ["TRACE", "DEBUG", "INFO ", "WARN ", "ERROR", "FATAL"];
exports.BayLog = BayLog;
//# sourceMappingURL=bayLog.js.map