"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BuiltInHarborDocker = void 0;
const harbor_1 = require("../harbor");
const dockerBase_1 = require("../base/dockerBase");
const bayLog_1 = require("../../bayLog");
const bayMessage_1 = require("../../bayMessage");
const symbol_1 = require("../../symbol");
const strUtil_1 = require("../../util/strUtil");
const bayserver_1 = require("../../bayserver");
const configException_1 = require("../../configException");
const groups_1 = require("../../util/groups");
class BuiltInHarborDocker extends dockerBase_1.DockerBase {
    constructor() {
        super(...arguments);
        this.charset = BuiltInHarborDocker.DEFAULT_CHARSET;
        this.controlPort = BuiltInHarborDocker.DEFAULT_CONTROL_PORT;
        this.fileSendMethod = BuiltInHarborDocker.DEFAULT_SEND_FILE_METHOD;
        this.gzipComp = BuiltInHarborDocker.DEFAULT_GZIP_COMP;
        this.keepTimeoutSec = BuiltInHarborDocker.DEFAULT_KEEP_TIMEOUT_SEC;
        this.maxShips = BuiltInHarborDocker.DEFAULT_MAX_SHIPS;
        this.multiCore = BuiltInHarborDocker.DEFAULT_MULTI_CORE;
        this.numGrandAgents = BuiltInHarborDocker.DEFAULT_GRAND_AGENTS;
        this.numTainRunners = BuiltInHarborDocker.DEFAULT_TRAIN_RUNNERS;
        this.numTaxiRunners = BuiltInHarborDocker.DEFAULT_TAXI_RUNNERS;
        this.pidFile = BuiltInHarborDocker.DEFAULT_PID_FILE;
        this.redirectFile = null;
        this.socketTimeoutSec = BuiltInHarborDocker.DEFAULT_SOCKET_TIMEOUT_SEC;
        this.tourBufferSize = BuiltInHarborDocker.DEFAULT_TOUR_BUFFER_SIZE;
        this.traceHeader = false;
    }
    init(ini, parent) {
        super.init(ini, parent);
        if (this.numGrandAgents <= 0)
            this.numGrandAgents = 4;
        if (this.numTainRunners <= 0)
            this.numTainRunners = 1;
        if (this.maxShips <= 0)
            this.maxShips = BuiltInHarborDocker.DEFAULT_MAX_SHIPS;
        if (this.maxShips < BuiltInHarborDocker.DEFAULT_MAX_SHIPS) {
            this.maxShips = BuiltInHarborDocker.DEFAULT_MAX_SHIPS;
            bayLog_1.BayLog.warn(bayMessage_1.BayMessage.get(symbol_1.Symbol.CFG_MAX_SHIPS_IS_TO_SMALL, this.maxShips));
        }
        if (!this.multiCore) {
            bayLog_1.BayLog.warn(bayMessage_1.BayMessage.get(symbol_1.Symbol.CFG_SINGLE_CORE_NOT_SUPPORTED));
            this.multiCore = true;
        }
    }
    //////////////////////////////////////////////////////
    // Implements DockerBase
    //////////////////////////////////////////////////////
    initDocker(dkr) {
        switch (dkr.getType()) {
            case "trouble":
                this.trouble = dkr;
                break;
            default:
                return super.initDocker(dkr);
        }
    }
    initKeyVal(kv) {
        switch (kv.key.toLowerCase()) {
            default:
                return false;
            case "loglevel":
                bayLog_1.BayLog.setLogLevel(kv.value);
                break;
            case "charset":
                let charset = strUtil_1.StrUtil.parseCharset(kv.value);
                if (strUtil_1.StrUtil.isSet(charset))
                    this.charset = charset;
                break;
            /*
        case "locale":
            this.locale = LocaleUtil.parseLocale(kv.value);
            break;

             */
            case "groups": {
                let fname;
                try {
                    fname = bayserver_1.BayServer.parsePath(kv.value);
                }
                catch (e) {
                    bayLog_1.BayLog.error_e(e);
                    throw new configException_1.ConfigException(kv.fileName, kv.lineNo, bayMessage_1.BayMessage.get(symbol_1.Symbol.CFG_FILE_NOT_FOUND, kv.value));
                }
                groups_1.Groups.init(fname);
                break;
            }
            case "grandagents":
                this.numGrandAgents = Number.parseInt(kv.value);
                break;
            case "trains":
                this.numTainRunners = Number.parseInt(kv.value);
                break;
            case "taxis":
            case "taxies":
                this.numTaxiRunners = Number.parseInt(kv.value);
                break;
            case "maxships":
                this.maxShips = Number.parseInt(kv.value);
                break;
            case "timeout":
                this.socketTimeoutSec = Number.parseInt(kv.value);
                break;
            case "keeptimeout":
                this.keepTimeoutSec = Number.parseInt(kv.value);
                break;
            case "tourbuffersize":
                this.tourBufferSize = strUtil_1.StrUtil.parseSize(kv.value);
                break;
            case "traceheader":
                this.traceHeader = strUtil_1.StrUtil.parseBool(kv.value);
                break;
            case "redirectfile":
                this.redirectFile = kv.value;
                break;
            case "controlport":
                this.controlPort = Number.parseInt(kv.value);
                break;
            case "multicore":
                this.multiCore = strUtil_1.StrUtil.parseBool(kv.value);
                break;
            case "gzipcomp":
                this.gzipComp = strUtil_1.StrUtil.parseBool(kv.value);
                break;
            case "sendfilemethod":
                break;
            case "pidfile":
                this.pidFile = kv.value;
                break;
        }
        return true;
    }
    //////////////////////////////////////////////////////
    // Implements Harbor
    //////////////////////////////////////////////////////
    getType() {
        return "harbor";
    }
    getCharset() {
        return this.charset;
    }
    getControlPort() {
        return this.controlPort;
    }
    getFileSendMethod() {
        return this.fileSendMethod;
    }
    getGzipComp() {
        return this.gzipComp;
    }
    getKeepTimeoutSec() {
        return this.keepTimeoutSec;
    }
    getLocale() {
        return this.locale;
    }
    getMaxShips() {
        return this.maxShips;
    }
    isMultiCore() {
        return this.multiCore;
    }
    getNumGrandAgents() {
        return this.numGrandAgents;
    }
    getNumTainRunners() {
        return this.numTainRunners;
    }
    getNumTaxiRunners() {
        return this.numTaxiRunners;
    }
    getPidFile() {
        return this.pidFile;
    }
    getRedirectFile() {
        return this.redirectFile;
    }
    getSocketTimeoutSec() {
        return this.socketTimeoutSec;
    }
    getTourBufferSize() {
        return this.tourBufferSize;
    }
    isTraceHeader() {
        return this.traceHeader;
    }
    getTrouble() {
        return this.trouble;
    }
}
BuiltInHarborDocker.DEFAULT_MAX_SHIPS = 256;
BuiltInHarborDocker.DEFAULT_GRAND_AGENTS = 0;
BuiltInHarborDocker.DEFAULT_TRAIN_RUNNERS = 8;
BuiltInHarborDocker.DEFAULT_TAXI_RUNNERS = 8;
BuiltInHarborDocker.DEFAULT_SOCKET_TIMEOUT_SEC = 300;
BuiltInHarborDocker.DEFAULT_KEEP_TIMEOUT_SEC = 20;
BuiltInHarborDocker.DEFAULT_TOUR_BUFFER_SIZE = 1024 * 1024; // 1M
BuiltInHarborDocker.DEFAULT_CHARSET = "UTF-8";
BuiltInHarborDocker.DEFAULT_CONTROL_PORT = -1;
BuiltInHarborDocker.DEFAULT_SEND_FILE_METHOD = harbor_1.FILE_SEND_METHOD_TAXI;
BuiltInHarborDocker.DEFAULT_MULTI_CORE = true;
BuiltInHarborDocker.DEFAULT_GZIP_COMP = false;
BuiltInHarborDocker.DEFAULT_PID_FILE = "bayserver.pid";
exports.BuiltInHarborDocker = BuiltInHarborDocker;
module.exports = {
    createDocker: () => new BuiltInHarborDocker()
};
//# sourceMappingURL=builtInHarborDocker.js.map