"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BuiltInTownDocker = void 0;
const dockerBase_1 = require("../base/dockerBase");
const town_1 = require("../town");
const sysUtil_1 = require("../../util/sysUtil");
const configException_1 = require("../../configException");
const bayMessage_1 = require("../../bayMessage");
const symbol_1 = require("../../symbol");
const bayserver_1 = require("../../bayserver");
class BuiltInTownDocker extends dockerBase_1.DockerBase {
    constructor() {
        super(...arguments);
        this.clubList = [];
        this.permissionList = [];
        this.rerouteList = [];
    }
    //////////////////////////////////////////////////////
    // Implements Docker
    //////////////////////////////////////////////////////
    init(elm, parent) {
        let arg = elm.arg;
        if (!arg.startsWith("/"))
            arg = "/" + arg;
        this.name = arg;
        if (!this.name.endsWith("/"))
            this.name = this.name + "/";
        this.city = parent;
        super.init(elm, parent);
    }
    //////////////////////////////////////////////////////
    // Implements DockerBase
    //////////////////////////////////////////////////////
    initDocker(dkr) {
        switch (dkr.getType()) {
            case "club":
                this.clubList.push(dkr);
                break;
            case "permission":
                this.permissionList.push(dkr);
                break;
            case "reroute":
                this.rerouteList.push(dkr);
                break;
            default:
                return super.initDocker(dkr);
        }
        return true;
    }
    initKeyVal(kv) {
        switch (kv.key.toLowerCase()) {
            default:
                return false;
            case "location": {
                this.location = kv.value;
                if (!sysUtil_1.SysUtil.isAbsolutePath(this.location))
                    this.location = bayserver_1.BayServer.getLocation(this.location);
                if (!sysUtil_1.SysUtil.isDirectory(this.location))
                    throw new configException_1.ConfigException(kv.fileName, kv.lineNo, bayMessage_1.BayMessage.get(symbol_1.Symbol.CFG_INVALID_LOCATION, this.location));
                //this.location = fs.realpath(this.location)
                break;
            }
            case "index":
            case "welcome":
                this.welcome = kv.value;
                break;
        }
        return true;
    }
    //////////////////////////////////////////////////////
    // Implements Town
    //////////////////////////////////////////////////////
    getName() {
        return this.name;
    }
    getCity() {
        return this.city;
    }
    getLocation() {
        return this.location;
    }
    getWelcomeFile() {
        return this.welcome;
    }
    getClubs() {
        return this.clubList;
    }
    reroute(uri) {
        for (const r of this.rerouteList) {
            uri = r.reroute(this, uri);
        }
        return uri;
    }
    matches(uri) {
        if (uri.startsWith(this.name))
            return town_1.MATCH_TYPE_MATCHED;
        else if (uri + "/" == this.name)
            return town_1.MATCH_TYPE_CLOSE;
        else
            return town_1.MATCH_TYPE_NOT_MATCHED;
    }
    checkAdmitted(tour) {
        for (const p of this.permissionList) {
            p.tourAdmitted(tour);
        }
    }
}
exports.BuiltInTownDocker = BuiltInTownDocker;
module.exports = {
    createDocker: () => new BuiltInTownDocker()
};
//# sourceMappingURL=builtInTownDocker.js.map