import { LogItem } from "./logItem";
import { Tour } from "../../tour/tour";
export declare class TextItem extends LogItem {
    /** text to print */
    text: string;
    constructor(text: string);
    getItem(tour: Tour): string;
}
/**
 * Return null result
 */
export declare class NullItem extends LogItem {
    static factory: () => NullItem;
    getItem(tour: Tour): string;
}
/**
 * Return remote IP address (%a)
 */
export declare class RemoteHostItem extends LogItem {
    static factory: () => RemoteHostItem;
    getItem(tour: Tour): string;
}
/**
 * Return local IP address (%A)
 */
export declare class ServerIpItem extends LogItem {
    static factory: () => ServerIpItem;
    getItem(tour: Tour): string;
}
/**
 * Return number of bytes that is sent from clients (Except HTTP headers)
 * (%B)
 */
export declare class RequestBytesItem1 extends LogItem {
    static factory: () => RequestBytesItem1;
    getItem(tour: Tour): string;
}
/**
 * Return number of bytes that is sent from clients in CLF format (Except
 * HTTP headers) (%b)
 */
export declare class RequestBytesItem2 extends LogItem {
    static factory: () => RequestBytesItem2;
    getItem(tour: Tour): string;
}
/**
 * Return connection status (%c)
 */
export declare class ConnectionStatusItem extends LogItem {
    static factory: () => ConnectionStatusItem;
    getItem(tour: Tour): string;
}
/**
 * Return file name (%f)
 */
export declare class FileNameItem extends LogItem {
    static factory: () => FileNameItem;
    getItem(tour: Tour): string;
}
/**
 * Return remote log name (%l)
 */
export declare class RemoteLogItem extends LogItem {
    static factory: () => RemoteLogItem;
    getItem(tour: Tour): string;
}
/**
 * Return request protocol (%m)
 */
export declare class ProtocolItem extends LogItem {
    static factory: () => ProtocolItem;
    getItem(tour: Tour): string;
}
/**
 * Return requested header (%{Foobar}i)
 */
export declare class RequestHeaderItem extends LogItem {
    static factory: () => RequestHeaderItem;
    /** Header name */
    name: string;
    init(param: string): void;
    getItem(tour: Tour): string;
}
/**
 * Return request method (%m)
 */
export declare class MethodItem extends LogItem {
    static factory: () => MethodItem;
    getItem(tour: Tour): string;
}
/**
 * Return responde header (%{Foobar}o)
 */
export declare class ResponseHeaderItem extends LogItem {
    static factory: () => ResponseHeaderItem;
    /** Header name */
    name: string;
    init(param: string): void;
    getItem(tour: Tour): string;
}
/**
 * The server port (%p)
 */
export declare class PortItem extends LogItem {
    static factory: () => PortItem;
    getItem(tour: Tour): string;
}
/**
 * Return query string (%q)
 */
export declare class QueryStringItem extends LogItem {
    static factory: () => QueryStringItem;
    getItem(tour: Tour): string;
}
/**
 * The start line (%r)
 */
export declare class StartLineItem extends LogItem {
    static factory: () => StartLineItem;
    getItem(tour: Tour): string;
}
/**
 * Return status (%s)
 */
export declare class StatusItem extends LogItem {
    static factory: () => StatusItem;
    getItem(tour: Tour): string;
}
/**
 * Return current time (%{format}t)
 */
export declare class TimeItem extends LogItem {
    static factory: () => TimeItem;
    init(param: string | null): void;
    getItem(tour: Tour): string;
}
/**
 * Return how long request took (%T)
 */
export declare class IntervalItem extends LogItem {
    static factory: () => IntervalItem;
    getItem(tour: Tour): string;
}
/**
 * Return remote user (%u)
 */
export declare class RemoteUserItem extends LogItem {
    static factory: () => RemoteUserItem;
    getItem(tour: Tour): string;
}
/**
 * Return requested URL(not content query string) (%U)
 */
export declare class RequestUrlItem extends LogItem {
    static factory: () => RequestUrlItem;
    getItem(tour: Tour): string;
}
/**
 * Return the server name (%v)
 */
export declare class ServerNameItem extends LogItem {
    static factory: () => ServerNameItem;
    getItem(tour: Tour): string;
}
//# sourceMappingURL=logItems.d.ts.map