"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WarpDataListener = void 0;
const nextSocketAction_1 = require("../../agent/nextSocketAction");
const bayLog_1 = require("../../bayLog");
const warpData_1 = require("./warpData");
const tour_1 = require("../../tour/tour");
const httpStatus_1 = require("../../util/httpStatus");
const ioException_1 = require("../../util/ioException");
class WarpDataListener {
    constructor(ship) {
        this.ship = ship;
    }
    toString() {
        return this.ship.toString();
    }
    notifyHandshakeDone(protocol) {
        this.ship.protocolHandler.verifyProtocol(protocol);
        //  Send pending packet
        //this.ship.agent.nonBlockingHandler.askToWrite(ship.ch);
        return nextSocketAction_1.NextSocketAction.CONTINUE;
    }
    notifyConnect() {
        bayLog_1.BayLog.debug("%s notifyConnect", this);
        this.ship.connected = true;
        for (const wp of this.ship.tourMap.values()) {
            wp.tour.checkTourId(wp.id);
            warpData_1.WarpData.get(wp.tour).start();
        }
        return nextSocketAction_1.NextSocketAction.CONTINUE;
    }
    notifyRead(buf, adr) {
        return this.ship.protocolHandler.bytesReceived(buf);
    }
    notifyEof() {
        bayLog_1.BayLog.debug("%s EOF detected", this);
        if (this.ship.tourMap.size == 0) {
            bayLog_1.BayLog.debug("%s No warp tour. only close", this);
            return nextSocketAction_1.NextSocketAction.CLOSE;
        }
        for (const [warpId, wp] of this.ship.tourMap.entries()) {
            wp.tour.checkTourId(wp.id);
            if (!wp.tour.res.headerSent) {
                bayLog_1.BayLog.debug("%s Send ServiceUnavailable: tur=%s", this, wp.tour);
                wp.tour.res.sendError(tour_1.Tour.TOUR_ID_NOCHECK, httpStatus_1.HttpStatus.SERVICE_UNAVAILABLE, "Server closed on reading headers");
            }
            else {
                // NOT treat EOF as Error
                bayLog_1.BayLog.debug("%s EOF is not an error (send end content): tur=%s", this, wp.tour);
                try {
                    wp.tour.res.endContent(tour_1.Tour.TOUR_ID_NOCHECK);
                }
                catch (e) {
                    if (e instanceof ioException_1.IOException) {
                        bayLog_1.BayLog.debug_e(e, "%s end content error: tur=%s", this, wp.tour);
                    }
                    else {
                        throw e;
                    }
                }
            }
        }
        this.ship.tourMap = new Map();
        return nextSocketAction_1.NextSocketAction.CLOSE;
    }
    notifyError(err) {
        bayLog_1.BayLog.debug_e(err, "%s notifyError: %s", this, err.message);
        this.ship.notifyErrorToOwnerTour(httpStatus_1.HttpStatus.SERVICE_UNAVAILABLE, this + " server closed");
    }
    notifyProtocolError(e) {
        bayLog_1.BayLog.error_e(e);
        this.ship.notifyErrorToOwnerTour(httpStatus_1.HttpStatus.SERVICE_UNAVAILABLE, e.message);
        return true;
    }
    checkTimeout(durationSec) {
        if (this.ship.isTimeout(durationSec)) {
            this.ship.notifyErrorToOwnerTour(httpStatus_1.HttpStatus.GATEWAY_TIMEOUT, this + " server timeout");
            return true;
        }
        else
            return false;
    }
    ;
    notifyClose() {
        bayLog_1.BayLog.debug(this + " notifyClose");
        this.ship.endShip();
    }
}
exports.WarpDataListener = WarpDataListener;
//# sourceMappingURL=warpDataListener.js.map