"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PacketPartAccessor = void 0;
const buffer_1 = require("buffer");
const sink_1 = require("../sink");
class PacketPartAccessor {
    constructor(pkt, start, maxLen) {
        this.packet = pkt;
        this.start = start;
        this.maxLen = maxLen;
        this.pos = 0;
    }
    putByte(b) {
        this.putBytes(buffer_1.Buffer.from([b]), 0, 1);
    }
    putBytes(buf, ofs = 0, len = buf.length) {
        if (len > 0) {
            this.checkWrite(len);
            while (this.start + this.pos + len > this.packet.buf.length) {
                this.packet.expand();
            }
            buf.copy(this.packet.buf, this.start + this.pos, ofs, ofs + len);
            this.forward(len);
        }
    }
    putShort(val) {
        let h = val >> 8 & 0xFF;
        let l = val & 0xFF;
        this.putBytes(buffer_1.Buffer.from([h, l]), 0, 2);
    }
    putInt(val) {
        let b1 = val >> 24 & 0xFF;
        let b2 = val >> 16 & 0xFF;
        let b3 = val >> 8 & 0xFF;
        let b4 = val & 0xFF;
        this.putBytes(buffer_1.Buffer.from([b1, b2, b3, b4]), 0, 4);
    }
    putString(s) {
        if (s == null)
            throw new Error();
        let tmpBuf = buffer_1.Buffer.from(s, "latin1");
        this.putBytes(tmpBuf, 0, tmpBuf.length);
    }
    getByte() {
        let buf = buffer_1.Buffer.alloc(1);
        this.getBytes(buf, 0, 1);
        return buf[0] & 0xFF;
    }
    getBytes(buf, ofs = 0, len = buf.length) {
        if (buf == null)
            throw new Error("nullPo");
        this.checkRead(len);
        this.packet.buf.copy(buf, ofs, this.start + this.pos, this.start + this.pos + len);
        this.pos += len;
    }
    getShort() {
        let h = this.getByte();
        let l = this.getByte();
        return h << 8 | l;
    }
    getInt() {
        let b1 = this.getByte();
        let b2 = this.getByte();
        let b3 = this.getByte();
        let b4 = this.getByte();
        return b1 << 24 | b2 << 16 | b3 << 8 | b4;
    }
    checkRead(len) {
        let maxLen = (this.maxLen >= 0) ? this.maxLen : this.packet.bufLen - this.start;
        if (this.pos + len > maxLen)
            throw new sink_1.Sink("Invalid index");
    }
    checkWrite(len) {
        if (this.maxLen > 0 && this.pos + len > this.maxLen)
            throw new sink_1.Sink("Buffer overflow");
    }
    forward(len) {
        this.pos += len;
        if (this.start + this.pos > this.packet.bufLen)
            this.packet.bufLen = this.start + this.pos;
    }
}
exports.PacketPartAccessor = PacketPartAccessor;
//# sourceMappingURL=packetPartAccessor.js.map