"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PacketStore = void 0;
const objectStore_1 = require("../util/objectStore");
const bayLog_1 = require("../bayLog");
const strUtil_1 = require("../util/strUtil");
const grandAgent_1 = require("../agent/grandAgent");
class AgentListener {
    add(agentId) {
        for (const info of Object.values(PacketStore.protoMap)) {
            info.addAgent(agentId);
        }
    }
    remove(agentId) {
        for (const info of Object.values(PacketStore.protoMap)) {
            info.removeAgent(agentId);
        }
    }
}
class ProtocolInfo {
    constructor(proto, packetFactory) {
        /** Agent ID => PacketStore */
        this.stores = {};
        this.protocol = proto;
        this.packetFactory = packetFactory;
    }
    newStore() {
        return new PacketStore(this.protocol, this.packetFactory);
    }
    addAgent(agtId) {
        let store = new PacketStore(this.protocol, this.packetFactory);
        this.stores[agtId] = store;
    }
    removeAgent(agtId) {
        delete this.stores[agtId];
    }
}
/**
 * Packet pool
 * @param <P> Packet
 * @param <T> Type of packet
 */
class PacketStore {
    constructor(protocol, factory) {
        this.storeMap = {};
        this.protocol = protocol;
        this.factory = factory;
    }
    reset() {
        for (const [type, store] of Object.entries(this.storeMap)) {
            store.reset();
        }
    }
    rent(typ) {
        var store = this.storeMap[typ];
        if (store == null) {
            store = new objectStore_1.ObjectStore(() => this.factory.createPacket(typ));
            this.storeMap[typ] = store;
        }
        return store.rent();
    }
    Return(pkt) {
        let store = this.storeMap[pkt.type];
        store.Return(pkt);
    }
    /**
     * print memory usage
     */
    printUsage(indent) {
        bayLog_1.BayLog.info("%sPacketStore(%s) usage nTypes=%d", strUtil_1.StrUtil.indent(indent), this.protocol, Object.entries(this.storeMap).length);
        Object.keys(this.storeMap).forEach(type => {
            bayLog_1.BayLog.info("%sType: %s", strUtil_1.StrUtil.indent(indent + 1), type);
            this.storeMap[type].printUsage(indent + 2);
        });
    }
    //////////////////////////////////////////////////////
    // Class methods
    //////////////////////////////////////////////////////
    static init() {
        grandAgent_1.GrandAgent.addLifecycleListener(new AgentListener());
    }
    static registerProtocol(protocol, pktFactory) {
        if (!(protocol in this.protoMap)) {
            this.protoMap[protocol] = new ProtocolInfo(protocol, pktFactory);
        }
    }
    static getStore(protocol, agtId) {
        return this.protoMap[protocol].stores[agtId];
    }
    static getStores(agentId) {
        let storeList = [];
        for (const info of Object.values(this.protoMap)) {
            storeList.push(info.stores[agentId]);
        }
        return storeList;
    }
}
PacketStore.protoMap = {};
exports.PacketStore = PacketStore;
//# sourceMappingURL=packetStore.js.map