"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SendFileYacht = void 0;
const yacht_1 = require("../watercraft/yacht");
const bayLog_1 = require("../bayLog");
const nextSocketAction_1 = require("../agent/nextSocketAction");
const sink_1 = require("../sink");
class SendFileYacht extends yacht_1.Yacht {
    constructor() {
        super();
        this.reset();
    }
    init(tur, file, fileLen, tp) {
        super.initYacht();
        bayLog_1.BayLog.debug("%s init file=%s", this, file);
        this.tour = tur;
        this.tourId = tur.tourId;
        this.file = file;
        this.fileLen = fileLen;
        tur.res.setConsumeListener((len, resume) => {
            if (resume) {
                tp.openValve();
            }
        });
    }
    toString() {
        return "fyacht#" + this.yachtId + "/" + this.objectId + " tour=" + this.tour + " id=" + this.tourId;
    }
    //////////////////////////////////////////////////////
    // Implements Reusable
    //////////////////////////////////////////////////////
    reset() {
        this.fileWroteLen = 0;
        this.tourId = 0;
        this.fileLen = 0;
        this.tour = null;
    }
    //////////////////////////////////////////////////////
    // Implements DataListener
    //////////////////////////////////////////////////////
    notifyRead(buf, adr) {
        this.checkInitialized();
        this.fileWroteLen += buf.length;
        bayLog_1.BayLog.debug("%s read file %d bytes: total=%d/%d", this, buf.length, this.fileWroteLen, this.fileLen);
        let available = this.tour.res.sendContent(this.tourId, buf, 0, buf.length);
        if (available) {
            return nextSocketAction_1.NextSocketAction.CONTINUE;
        }
        else {
            return nextSocketAction_1.NextSocketAction.SUSPEND;
        }
    }
    notifyEof() {
        this.checkInitialized();
        bayLog_1.BayLog.debug("%s EOF(^o^) %s", this, this.file);
        this.tour.res.endContent(this.tourId);
        return nextSocketAction_1.NextSocketAction.CLOSE;
    }
    notifyError(err) {
        this.checkInitialized();
        bayLog_1.BayLog.debug_e(err, "%s Error: %s", this, err.message);
        this.tour.res.sendError(this.tourId);
    }
    notifyClose() {
        bayLog_1.BayLog.debug("File closed: %s", this.file);
    }
    checkTimeout(durationSec) {
        throw new sink_1.Sink();
    }
    checkInitialized() {
        if (this.tour == null)
            throw new sink_1.Sink("Invalid yacht");
        this.tour.checkTourId(this.tourId);
    }
}
exports.SendFileYacht = SendFileYacht;
//# sourceMappingURL=sendFileYacht.js.map