"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TourStore = void 0;
const tour_1 = require("./tour");
const sink_1 = require("../sink");
const bayLog_1 = require("../bayLog");
const strUtil_1 = require("../util/strUtil");
const grandAgent_1 = require("../agent/grandAgent");
class AgentListener {
    add(agentId) {
        TourStore.stores.set(agentId, new TourStore());
    }
    remove(agentId) {
        TourStore.stores.delete(agentId);
    }
}
class TourStore {
    constructor() {
        this.freeTours = [];
        this.activeTourMap = new Map();
    }
    get(key) {
        return this.activeTourMap.get(key);
    }
    rent(key, force) {
        let tur = this.get(key);
        if (tur != null)
            throw new sink_1.Sink("Tour is active: " + tur);
        if (this.freeTours.length > 0) {
            //BayLog.debug("rent: key=%d from free tours", key);
            tur = this.freeTours.pop();
        }
        else {
            if (!force && (this.activeTourMap.size >= TourStore.maxCount)) {
                return null;
            }
            else {
                tur = new tour_1.Tour();
            }
        }
        this.activeTourMap.set(key, tur);
        return tur;
    }
    Return(key) {
        if (!this.activeTourMap.has(key)) {
            throw new sink_1.Sink("Tour is not active key=: " + key);
        }
        //BayLog.debug("return: key=%d Active tour count: before=%d", key, activeTourMap.size());
        let tur = this.activeTourMap.get(key);
        this.activeTourMap.delete(key);
        //BayLog.debug("return: key=%d Active tour count: after=%d", key, activeTourMap.size());
        bayLog_1.BayLog.debug("%s reset", tur);
        tur.reset();
        this.freeTours.push(tur);
    }
    /**
     * print memory usage
     */
    printUsage(indent) {
        bayLog_1.BayLog.info("%sTour store usage:", strUtil_1.StrUtil.indent(indent));
        bayLog_1.BayLog.info("%sfreeList: %d", strUtil_1.StrUtil.indent(indent + 1), this.freeTours.length);
        bayLog_1.BayLog.info("%sactiveList: %d", strUtil_1.StrUtil.indent(indent + 1), this.activeTourMap.size);
        if (bayLog_1.BayLog.isDebug()) {
            for (const obj of this.activeTourMap.values()) {
                bayLog_1.BayLog.debug("%s%s", strUtil_1.StrUtil.indent(indent + 1), obj);
            }
        }
    }
    static init(maxTourCount) {
        TourStore.maxCount = maxTourCount;
        grandAgent_1.GrandAgent.addLifecycleListener(new AgentListener());
    }
    static getStore(agentId) {
        return this.stores.get(agentId);
    }
    static initClass() {
        this.stores = new Map();
    }
}
TourStore.MAX_TOURS = 128;
/** Agent ID => TourStore */
TourStore.stores = null;
exports.TourStore = TourStore;
TourStore.initClass();
//# sourceMappingURL=tourStore.js.map