"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CGIUtil = void 0;
const bayserver_1 = require("../bayserver");
const strUtil_1 = require("./strUtil");
const httpHeaders_1 = require("./httpHeaders");
const sysUtil_1 = require("./sysUtil");
const bayLog_1 = require("../bayLog");
const process_1 = require("process");
class CGIUtil {
    static getEnvHash(path, docRoot, scriptBase, tur) {
        let env = {};
        let callback = (name, value) => {
            env[name] = value;
        };
        CGIUtil.getEnv(path, docRoot, scriptBase, tur, callback);
        return env;
    }
    static getEnv(path, docRoot, scriptBase, tour, lis) {
        let reqHeaders = tour.req.headers;
        let ctype = reqHeaders.contentType();
        if (ctype != null) {
            let pos = ctype.indexOf("charset=");
            if (pos >= 0) {
                tour.req.charset = ctype.substring(pos + 8).trim();
            }
        }
        this.addEnv(lis, this.REQUEST_METHOD, tour.req.method);
        this.addEnv(lis, this.REQUEST_URI, tour.req.uri);
        this.addEnv(lis, this.SERVER_PROTOCOL, tour.req.protocol);
        this.addEnv(lis, this.GATEWAY_INTERFACE, "CGI/1.1");
        this.addEnv(lis, this.SERVER_NAME, tour.req.reqHost);
        this.addEnv(lis, this.SERVER_ADDR, tour.req.serverAddress);
        if (tour.req.reqPort >= 0)
            this.addEnv(lis, this.SERVER_PORT, tour.req.reqPort.toString());
        this.addEnv(lis, this.SERVER_SOFTWARE, bayserver_1.BayServer.getSoftwareName());
        this.addEnv(lis, this.CONTEXT_DOCUMENT_ROOT, docRoot);
        for (let name of tour.req.headers.names()) {
            let newVal = null;
            for (const value of tour.req.headers.values(name)) {
                if (newVal == null)
                    newVal = value;
                else {
                    newVal = newVal + "; " + value;
                }
            }
            name = name.toUpperCase().replace(new RegExp('-', 'g'), '_');
            if (name.startsWith("X_FORWARDED_")) {
                this.addEnv(lis, name, newVal);
            }
            else {
                switch (name) {
                    case this.CONTENT_TYPE:
                    case this.CONTENT_LENGTH:
                        this.addEnv(lis, name, newVal);
                        break;
                    default:
                        this.addEnv(lis, "HTTP_" + name, newVal);
                        break;
                }
            }
        }
        this.addEnv(lis, this.REMOTE_ADDR, tour.req.remoteAddress);
        this.addEnv(lis, this.REMOTE_PORT, tour.req.remotePort.toString());
        //addEnv(map, REMOTE_USER, "unknown");
        this.addEnv(lis, this.REQUEST_SCHEME, tour.isSecure ? "https" : "http");
        let tmpSecure = tour.isSecure;
        let fproto = tour.req.headers.get(httpHeaders_1.HttpHeaders.X_FORWARDED_PROTO);
        if (fproto != null) {
            tmpSecure = strUtil_1.StrUtil.eqIgnoreCase(fproto, "https");
        }
        if (tmpSecure)
            this.addEnv(lis, this.HTTPS, "on");
        this.addEnv(lis, this.QUERY_STRING, tour.req.queryString);
        this.addEnv(lis, this.SCRIPT_NAME, tour.req.scriptName);
        if (tour.req.pathInfo == null) {
            this.addEnv(lis, this.PATH_INFO, "");
        }
        else {
            this.addEnv(lis, this.PATH_INFO, tour.req.pathInfo);
            try {
                let pathTranslated = sysUtil_1.SysUtil.joinPath(docRoot, tour.req.pathInfo);
                this.addEnv(lis, this.PATH_TRANSLATED, pathTranslated);
            }
            catch (e) {
                bayLog_1.BayLog.error_e(e);
            }
        }
        if (!scriptBase.endsWith("/"))
            scriptBase = scriptBase + "/";
        this.addEnv(lis, this.SCRIPT_FILENAME, scriptBase + tour.req.scriptName.substring(path.length));
        this.addEnv(lis, this.PATH, process_1.env["PATH"]);
    }
    static addEnv(lis, key, value) {
        if (value == null)
            value = "";
        lis(key, value.toString());
    }
}
CGIUtil.REQUEST_METHOD = "REQUEST_METHOD";
CGIUtil.REQUEST_URI = "REQUEST_URI";
CGIUtil.SERVER_PROTOCOL = "SERVER_PROTOCOL";
CGIUtil.GATEWAY_INTERFACE = "GATEWAY_INTERFACE";
CGIUtil.SERVER_NAME = "SERVER_NAME";
CGIUtil.SERVER_PORT = "SERVER_PORT";
CGIUtil.QUERY_STRING = "QUERY_STRING";
CGIUtil.SCRIPT_NAME = "SCRIPT_NAME";
CGIUtil.SCRIPT_FILENAME = "SCRIPT_FILENAME";
CGIUtil.PATH_TRANSLATED = "PATH_TRANSLATED";
CGIUtil.PATH_INFO = "PATH_INFO";
CGIUtil.CONTENT_TYPE = "CONTENT_TYPE";
CGIUtil.CONTENT_LENGTH = "CONTENT_LENGTH";
CGIUtil.REMOTE_ADDR = "REMOTE_ADDR";
CGIUtil.REMOTE_PORT = "REMOTE_PORT";
CGIUtil.REMOTE_USER = "REMOTE_USER";
CGIUtil.HTTP_ACCEPT = "HTTP_ACCEPT";
CGIUtil.HTTP_COOKIE = "HTTP_COOKIE";
CGIUtil.HTTP_HOST = "HTTP_HOST";
CGIUtil.HTTP_USER_AGENT = "HTTP_USER_AGENT";
CGIUtil.HTTP_ACCEPT_ENCODING = "HTTP_ACCEPT_ENCODING";
CGIUtil.HTTP_ACCEPT_LANGUAGE = "HTTP_ACCEPT_LANGUAGE";
CGIUtil.HTTP_CONNECTION = "HTTP_CONNECTION";
CGIUtil.HTTP_UPGRADE_INSECURE_REQUESTS = "HTTP_UPGRADE_INSECURE_REQUESTS";
CGIUtil.HTTPS = "HTTPS";
CGIUtil.PATH = "PATH";
CGIUtil.SERVER_SIGNATURE = "SERVER_SIGNATURE";
CGIUtil.SERVER_SOFTWARE = "SERVER_SOFTWARE";
CGIUtil.SERVER_ADDR = "SERVER_ADDR";
CGIUtil.DOCUMENT_ROOT = "DOCUMENT_ROOT";
CGIUtil.REQUEST_SCHEME = "REQUEST_SCHEME";
CGIUtil.CONTEXT_PREFIX = "CONTEXT_PREFIX";
CGIUtil.CONTEXT_DOCUMENT_ROOT = "CONTEXT_DOCUMENT_ROOT";
CGIUtil.SERVER_ADMIN = "SERVER_ADMIN";
CGIUtil.REQUEST_TIME_FLOAT = "REQUEST_TIME_FLOAT";
CGIUtil.REQUEST_TIME = "REQUEST_TIME";
CGIUtil.UNIQUE_ID = "UNIQUE_ID";
exports.CGIUtil = CGIUtil;
//# sourceMappingURL=CGIUtil.js.map