"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Groups = exports.Group = void 0;
const md5Password_1 = require("./md5Password");
const bcfParser_1 = require("../bcf/bcfParser");
const bcfElement_1 = require("../bcf/bcfElement");
const strUtil_1 = require("./strUtil");
const bcfKeyVal_1 = require("../bcf/bcfKeyVal");
class Member {
    constructor(name, digest) {
        this.name = name;
        this.digest = digest;
    }
    validate(password) {
        if (password == null)
            return false;
        let dig = md5Password_1.Md5Password.encode(password);
        return this.digest == dig;
    }
}
class Group {
    constructor(name) {
        this.members = [];
        this.name = name;
    }
    add(name) {
        this.members.push(name);
    }
    validate(mName, pass) {
        if (!(mName in this.members))
            return false;
        let m = Groups.allMembers[mName];
        if (m == null)
            return false;
        return m.validate(pass);
    }
}
exports.Group = Group;
class Groups {
    static init(conf) {
        let p = new bcfParser_1.BcfParser();
        let doc = p.parse(conf);
        for (const o of doc.contentList) {
            if (o instanceof bcfElement_1.BcfElement) {
                let elm = o;
                if (strUtil_1.StrUtil.eqIgnoreCase(elm.name, "group")) {
                    this.initGroups(elm);
                }
                else if (strUtil_1.StrUtil.eqIgnoreCase(elm.name, "member")) {
                    this.initMembers(elm);
                }
            }
        }
    }
    static getGroup(name) {
        return this.allGroups[name];
    }
    //////////////////////////////////////////////////////
    // Private methods
    //////////////////////////////////////////////////////
    static initGroups(elm) {
        for (const o of elm.contentList) {
            if (o instanceof bcfKeyVal_1.BcfKeyVal) {
                let kv = o;
                let g = new Group(kv.key);
                this.allGroups[g.name] = g;
                let names = kv.value.split(" ");
                for (const mName of names) {
                    g.add(mName);
                }
            }
        }
    }
    static initMembers(elm) {
        for (const o of elm.contentList) {
            if (o instanceof bcfKeyVal_1.BcfKeyVal) {
                let kv = o;
                let m = new Member(kv.key, kv.value);
                this.allMembers[m.name] = m;
            }
        }
    }
}
Groups.allGroups = {};
Groups.allMembers = {};
exports.Groups = Groups;
//# sourceMappingURL=groups.js.map