export declare class HttpHeaders {
    /**
     * Known header names
     */
    static readonly HEADER_SEPARATOR: string;
    static readonly HEADER_SEPARATOR_BYTES: number;
    static readonly CONTENT_TYPE: string;
    static readonly CONTENT_LENGTH: string;
    static readonly CONTENT_ENCODING: string;
    static readonly HDR_TRANSFER_ENCODING: string;
    static readonly CONNECTION: string;
    static readonly AUTHORIZATION: string;
    static readonly WWW_AUTHENTICATE: string;
    static readonly STATUS: string;
    static readonly LOCATION: string;
    static readonly HOST: string;
    static readonly COOKIE: string;
    static readonly USER_AGENT: string;
    static readonly ACCEPT: string;
    static readonly ACCEPT_LANGUAGE: string;
    static readonly ACCEPT_ENCODING: string;
    static readonly UPGRADE_INSECURE_REQUESTS: string;
    static readonly SERVER: string;
    static readonly X_FORWARDED_HOST: string;
    static readonly X_FORWARDED_FOR: string;
    static readonly X_FORWARDED_PROTO: string;
    static readonly X_FORWARDED_PORT: string;
    static readonly CONNECTION_CLOSE: number;
    static readonly CONNECTION_KEEP_ALIVE: number;
    static readonly CONNECTION_UPGRADE: number;
    static readonly CONNECTION_UNKOWN: number;
    /** Status */
    status: number;
    /** Header hash */
    headers: Map<string, string[]>;
    constructor();
    toString(): string;
    copyTo(dst: HttpHeaders): void;
    /**
     * Get the header value as string
     */
    get(name: string): string;
    /**
     * Get the header value as int
     */
    getInt(name: string): number;
    /**
     * Update the header value by string
     */
    set(name: string, value: string): void;
    /**
     * Add a header value by string
     */
    add(name: string, value: string): void;
    /**
     * Get all the header name
     */
    names(): string[];
    /**
     * Get all the header values of specified header name
     */
    values(name: string): string[];
    /**
     * Check the existence of header
     */
    contains(name: string): boolean;
    remove(name: any): void;
    contentType(): string;
    setContentType(type: string): void;
    /**
     * Get content length
     *
     * @return content length. If there isn't a content length header, return
     *         -1.
     */
    contentLength(): number;
    setContentLength(length: number): void;
    getConnection(): number;
    clear(): void;
}
//# sourceMappingURL=httpHeaders.d.ts.map