"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.HttpStatus = void 0;
const bayLog_1 = require("../bayLog");
const bcfParser_1 = require("../bcf/bcfParser");
const bcfKeyVal_1 = require("../bcf/bcfKeyVal");
class HttpStatus {
    static description(statusCode) {
        let desc = HttpStatus.statusMap.get(statusCode);
        if (desc == null) {
            bayLog_1.BayLog.error("Status " + statusCode + " is invalid.");
            return "Unknown Status";
        }
        return desc;
    }
    static init(conf) {
        if (this.initialized)
            return;
        this.statusMap = new Map();
        let p = new bcfParser_1.BcfParser();
        let doc = p.parse(conf);
        for (const o of doc.contentList) {
            if (o instanceof bcfKeyVal_1.BcfKeyVal) {
                let kv = o;
                this.statusMap.set(Number.parseInt(kv.key), kv.value);
            }
        }
        this.initialized = true;
    }
}
HttpStatus.OK = 200;
HttpStatus.MOVED_PERMANENTLY = 301;
HttpStatus.MOVED_TEMPORARILY = 302;
HttpStatus.NOT_MODIFIED = 304;
HttpStatus.BAD_REQUEST = 400;
HttpStatus.UNAUTHORIZED = 401;
HttpStatus.FORBIDDEN = 403;
HttpStatus.NOT_FOUND = 404;
HttpStatus.UPGRADE_REQUIRED = 426;
HttpStatus.INTERNAL_SERVER_ERROR = 500;
HttpStatus.SERVICE_UNAVAILABLE = 503;
HttpStatus.GATEWAY_TIMEOUT = 504;
HttpStatus.HTTP_VERSION_NOT_SUPPORTED = 505;
HttpStatus.initialized = false;
exports.HttpStatus = HttpStatus;
//# sourceMappingURL=httpStatus.js.map