"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Message = void 0;
const strUtil_1 = require("./strUtil");
const bayLog_1 = require("../bayLog");
const bcfParser_1 = require("../bcf/bcfParser");
const bcfKeyVal_1 = require("../bcf/bcfKeyVal");
const sysUtil_1 = require("./sysUtil");
const util_1 = require("util");
class Message {
    constructor() {
        this.messages = new Map();
    }
    get(key, ...args) {
        var msg = this.messages.get(key);
        if (msg == null)
            msg = key;
        return (0, util_1.format)(msg, ...args);
    }
    init(conf, locale) {
        var lang = locale.language;
        this.initBcf(conf + ".bcf");
        if (strUtil_1.StrUtil.isSet(lang) && lang != "en")
            this.initBcf(conf + "_" + lang + ".bcf");
    }
    initBcf(file) {
        if (!sysUtil_1.SysUtil.isFile(file)) {
            bayLog_1.BayLog.warn("Cannot find message file: %s", file);
        }
        else {
            let p = new bcfParser_1.BcfParser();
            let doc = p.parse(file);
            for (const o of doc.contentList) {
                if (o instanceof bcfKeyVal_1.BcfKeyVal) {
                    let kv = o;
                    this.messages.set(kv.key, kv.value);
                }
            }
        }
    }
}
exports.Message = Message;
//# sourceMappingURL=message.js.map