"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ObjectStore = void 0;
const bayLog_1 = require("../bayLog");
const sink_1 = require("../sink");
const arrayUtil_1 = require("./arrayUtil");
const strUtil_1 = require("./strUtil");
class ObjectStore {
    constructor(factory = null) {
        this.freeList = [];
        this.activeList = [];
        this.factory = factory;
    }
    //////////////////////////////////////////////////////
    // Implements Reusable
    //////////////////////////////////////////////////////
    reset() {
        if (this.activeList.length > 0) {
            bayLog_1.BayLog.error("BUG?: There are %d active objects: %s", this.activeList.length, this.activeList);
            // for security
            this.freeList = [];
            this.activeList = [];
        }
    }
    //////////////////////////////////////////////////////
    // Other methods
    //////////////////////////////////////////////////////
    rent() {
        var obj;
        if (this.freeList.length == 0) {
            obj = this.factory();
        }
        else {
            obj = this.freeList.pop();
        }
        if (obj == null)
            throw new sink_1.Sink();
        this.activeList.push(obj);
        bayLog_1.BayLog.trace("%s rent object : %s free=%s", this, obj, this.freeList);
        return obj;
    }
    Return(obj, reuse = true) {
        bayLog_1.BayLog.trace("%s return object : %s free=%s", this, obj, this.freeList);
        if (this.freeList.includes(obj))
            throw new sink_1.Sink("This object already returned: " + obj);
        if (!this.activeList.includes(obj))
            throw new sink_1.Sink("This object is not active: " + obj);
        if (arrayUtil_1.ArrayUtil.remove(obj, this.activeList).length == 0)
            throw new sink_1.Sink("Cannot remove object: " + obj);
        if (reuse) {
            this.freeList.push(obj);
            obj.reset();
        }
    }
    /**
     * print memory usage
     */
    printUsage(indent) {
        bayLog_1.BayLog.info("%sfree list: %d", strUtil_1.StrUtil.indent(indent), this.freeList.length);
        bayLog_1.BayLog.info("%sactive list: %d", strUtil_1.StrUtil.indent(indent), this.activeList.length);
        if (bayLog_1.BayLog.isDebug()) {
            for (const obj of this.activeList) {
                bayLog_1.BayLog.debug("%s%s", strUtil_1.StrUtil.indent(indent + 1), obj);
            }
        }
    }
}
exports.ObjectStore = ObjectStore;
//# sourceMappingURL=objectStore.js.map