"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Ship = void 0;
const sink_1 = require("../sink");
const bayLog_1 = require("../bayLog");
const counter_1 = require("../util/counter");
class Ship {
    constructor() {
        this.objectId = Ship.oidCounter.next();
        this.shipId = Ship.INVALID_SHIP_ID;
    }
    init(ch, agent, pm) {
        if (this.initialized)
            throw new sink_1.Sink("Ship already initialized");
        this.shipId = Ship.idCounter.next();
        this.agent = agent;
        this.postman = pm;
        this.ch = ch;
        this.initialized = true;
        bayLog_1.BayLog.debug("%s Initialized", this);
    }
    reset() {
        //BayLog.debug("%s reset", this);
        this.initialized = false;
        this.postman.reset();
        this.postman = null; // for reloading certification
        this.protocolHandler = null;
        this.agent = null;
        this.shipId = Ship.INVALID_SHIP_ID;
        this.ch = null;
        this.keeping = false;
    }
    setProtocolHandler(protoHandler) {
        this.protocolHandler = protoHandler;
        protoHandler.ship = this;
        bayLog_1.BayLog.debug("%s protocol handler is set", this);
    }
    id() {
        return this.shipId;
    }
    protocol() {
        return this.protocolHandler == null ? "unknown" : this.protocolHandler.protocol();
    }
    resume(checkId) {
        this.checkShipId(checkId);
        this.postman.openValve();
    }
    checkShipId(shipId) {
        if (!this.initialized) {
            throw new sink_1.Sink(this + " Uninitialized ship (might be returned ship): " + shipId);
        }
        if (shipId == 0 || (shipId != Ship.SHIP_ID_NOCHECK && shipId != this.shipId)) {
            throw new sink_1.Sink(this + " Invalid ship id (might be returned ship): " + shipId);
        }
    }
}
Ship.SHIP_ID_NOCHECK = -1;
Ship.INVALID_SHIP_ID = 0;
Ship.oidCounter = new counter_1.Counter(1);
Ship.idCounter = new counter_1.Counter(1);
exports.Ship = Ship;
//# sourceMappingURL=ship.js.map